@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -20,7 +20,6 @@
 */
 
 
-#include "magics_ecmwf_log.h"
 #include "FortranMagics.h"
 #include "Timer.h"
 
@@ -79,8 +78,6 @@ FortranMagics::FortranMagics() :  drivers_(0), output_(0), action_(0), empty_(tr
 {
 	ASSERT (singleton_ == 0);
 	singleton_ = this;
-
-	writeMagLog("fortran");
 }
 
 
@@ -111,8 +108,7 @@ void FortranMagics::print(ostream& out)  const
 void FortranMagics::popen()
 {
    MagLog::info() << "popen()" << endl;
-
-   if(getEnvVariable("MAGPLUS_QUIET").empty() )
+   if(getEnvVariable("MAGPLUS_QUIET").empty() && !silent_ )
    {
 	MagLog::userInfo() << "------------------------------------------------------------------\n";
 	MagLog::userInfo() << "\n";
@@ -186,7 +182,7 @@ int FortranMagics::pclose()
 
 	Layout::reset();
 
-	if(getEnvVariable("MAGPLUS_QUIET").empty() )
+	if(getEnvVariable("MAGPLUS_QUIET").empty() && !silent_)
 	{
 	/*
 		MagLog::userInfo() << "------------------------------------------------------------------\n";
@@ -197,7 +193,7 @@ int FortranMagics::pclose()
 		{
 			MagLog::userInfo() << "  - "<<(*it)<<"\n";
 		}
-		
+
 		MagLog::userInfo() << "\n";
 	*/
 		MagLog::userInfo() << "------------------------------------------------------------------\n";
@@ -212,7 +208,10 @@ int FortranMagics::pclose()
 
 void FortranMagics::drivers()
 {
-	if (!drivers_)  drivers_ = new DriverManager();
+	if (!drivers_)
+		drivers_ = new DriverManager();
+	else
+		drivers_->clearDrivers();
 	if (!output_)   output_ = new OutputHandler();
 	output_->set(*drivers_);
 }
@@ -328,8 +327,12 @@ void FortranMagics::poverlay()
 
 void FortranMagics::pimport()
 {
+	actions();
 	ImportObjectHandler* object = new ImportObjectHandler();
-	later_.push_back(object);
+	if ( object->overlay_ )
+		later_.push_back(object);
+	else
+		top()->push_back(object);
 }
 
 
@@ -342,7 +345,6 @@ void FortranMagics::pnew(const string& type)
 		if ( empty_ ) return;
 		finish();
 		pop();
-		actions_.push(&FortranMagics::legend);
 		actions_.push(&FortranMagics::subpage);
 	}
 	if ( magCompare(type, "page") )
@@ -520,6 +522,86 @@ void FortranMagics::pmapgen()
 
 }
 
+#include "MetaData.h"
+#include "ContourLibrary.h"
+const char* FortranMagics::metagrib()
+{
+	GribDecoder grib;
+	ContourLibrary* library = MagTranslator<string, ContourLibrary>()("ecmwf");
+
+    		// Here we try call the Contour libry to set up visual properties...
+   	MetaDataCollector request,needAttributes;
+    MagDef attributes;
+
+
+	library->askId(request);
+	grib.visit(request);
+
+	StyleEntry style;
+	library->getStyle(request, attributes, style);
+
+	string print = getEnvVariable("MAGPLUS_DATA");
+	if ( print.size() ) {
+		cout << "Metadata for " << grib.file_name_ << endl;
+		for ( auto r = request.begin(); r != request.end(); ++r) {
+			cout << r->first << "=" << r->second << endl;
+		}
+		cout << "-----------------------------" << endl;
+	}
+	ostringstream out;
+	out << style;
+	static string temp;
+	temp = out.str();
+    return temp.c_str();
+
+}
+
+const char* FortranMagics::metanetcdf()
+{
+#ifdef HAVE_NETCDF
+	NetcdfDecoder netcdf;
+	ContourLibrary* library = MagTranslator<string, ContourLibrary>()("ecmwf");
+
+    // Here we try call the Contour libry to set up visual properties...
+   	MetaDataCollector request,needAttributes;
+    MagDef attributes;
+
+	library->askId(request);
+	netcdf.visit(request);
+
+	StyleEntry style;
+	library->getStyle(request, attributes, style);
+	ostringstream out;
+	out << style;
+	static string temp;
+	temp = out.str();
+    return temp.c_str();
+#endif
+}
+
+const char* FortranMagics::metainput()
+{
+
+	InputMatrix data;
+	ContourLibrary* library = MagTranslator<string, ContourLibrary>()("ecmwf");
+
+    // Here we try call the Contour libry to set up visual properties...
+   	MetaDataCollector request,needAttributes;
+    MagDef attributes;
+
+	library->askId(request);
+	data.visit(request);
+
+	StyleEntry style;
+	library->getStyle(request, attributes, style);
+	ostringstream out;
+	out << style;
+	static string temp;
+	temp = out.str();
+    return temp.c_str();
+
+}
+
 #ifdef HAVE_GRIB
 void FortranMagics::pgrib()
 {
@@ -586,10 +668,9 @@ void FortranMagics::pnetcdf()
 	action_ = new VisualAction();
 	action_->data(new NetcdfDecoder());
 	top()->push_back(action_);
-
-
 #endif
 }
+
 #include "InputData.h"
 void FortranMagics::pinput()
 {
