@@ -1,3 +1,13 @@
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
+
 /*! \file SceneVisitor.cc
     \brief Implementation of the Template class SceneVisitor.
     
@@ -34,6 +44,7 @@ bool SceneVisitor::reproject(BasicGraphicsObjectContainer&) const
 
 void  LayoutVisitor::redisplay(const BaseDriver& driver) const
 {
+	driver.redisplay(*layout_);
 	driver.redisplay(*current_);
 }
 
@@ -78,11 +89,13 @@ FrameVisitor::FrameVisitor()
 {
 	layout_ = new Layout();
 	layout_->name("frame");
+	background_ = "white";
 }
 
 FrameVisitor::~FrameVisitor()
 {
 }
+
 VerticalAxisVisitor::VerticalAxisVisitor(const DrawingVisitor&)
 {
 }
@@ -177,7 +190,7 @@ void LeftAxisVisitor::minortick(double& x1, double& x2, bool)
 double  LeftAxisVisitor::offsetTickLabel(double height, double from)
 {
 
-	double h =  ((current_->xmax_ - current_->xmin_)/current_->absoluteWidth()) * (2*height);
+	double h =  ((current_->xmax_ - current_->xmin_)/current_->absoluteWidth()) * (height*0.6);
 
 	return from - h;
 } 
@@ -222,7 +235,8 @@ void RightAxisVisitor::minortick(double& x1, double& x2, bool)
 
 double  RightAxisVisitor::offsetTickLabel(double height, double from)
 {
-	double h =  ((current_->xmax_ - current_->xmin_)/current_->absoluteWidth()) * (2*height);
+	cout << "height" << height << endl;
+	double h =  ((current_->xmax_ - current_->xmin_)*current_->absoluteWidth()) / (height);
 	return from + h;
 
 }
