@@ -104,6 +104,11 @@ protected:
 	 vector<TextVisitor*>   texts_;
 	 vector<LayoutVisitor*> components_;
 	
+	 string drawing_background_colour_;
+	 bool frameIt_;
+	 Colour frameColour_;
+	 LineStyle frameStyle_;
+	 int frameThickness_;
 	
 	 // Infomation about the zoom! 
 	 string id_;
