@@ -90,7 +90,7 @@ void VisualAction::visit(DrawingVisitor& drawing)
 {
 	if ( !data_ || ( data_ && !data_->valid() ) || visdefs_.empty() )
 	{
-		MagLog::warning() << " Check data or visual action!" << endl;
+		MagLog::info() << " Check data or visual action!" << endl;
 		return;
 	}
 	data_->getReady(drawing.transformation());
@@ -102,6 +102,11 @@ void VisualAction::visit(DrawingVisitor& drawing)
 		(**visdef)(*data_, drawing.layout()); // Now the visualObject ahs the responsability to reproject!
 	}
 }
+void VisualAction::visit(FrameVisitor& frame)
+{
+	frame.blankIt();
+	
+}
 
 
 void VisualAction::visit(HistoVisitor& drawing)
@@ -132,7 +137,7 @@ void VisualAction::visit(HistoVisitor& drawing)
 void VisualAction::visit(Transformation& transformation)
 {
 	if ( !data_ || !data_->valid() || visdefs_.empty() ) {
-		MagLog::warning() << " No proper action defined!" << endl;
+		MagLog::info() << " No proper action defined!" << endl;
 		return;
 	}
 	data_->visit(transformation);	
@@ -248,9 +253,8 @@ void VisualAnimation::prepare()
 		return;
 	
 	layer_ = new StepLayer();
-	layer_->name(loop_->name());
-	layer_->id(loop_->name()); 
-	layer_->uniqueId(loop_->iconId());
+	layer_->id(loop_->id());
+	
 	loop_->visit(*layer_);
 	
 	for ( vector<Visdef* >::iterator visdef = this->visdefs_.begin(); visdef != this->visdefs_.end(); ++visdef)
@@ -322,8 +326,17 @@ bool VisualAction::needLegend()
 
 void VisualAction::visit(SceneLayer& layer, vector<LayoutVisitor*>& visitors)
 {
+
+	if ( !data_ || ( data_ && !data_->valid() ) || visdefs_.empty() )
+	{
+		MagLog::info() << " Check data or visual action!" << endl;
+		return;
+	}
+	
 	layer_ = new StaticLayer(this);
 
+	
+	layer_->icon(*data_);
 	if ( data_ ) 
 		data_->visit(*layer_);
  	layer.add(layer_);
