@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -17,7 +17,6 @@
 */
 
 
-#include "magics_ecmwf_log.h"
 #include "XmlMagics.h"
 #include "XmlReader.h"
 #include "MagException.h"
@@ -74,8 +73,6 @@ XmlMagics::XmlMagics() : root_(0),
 	geographical_(true),
 	driversToSet_(true)
 {
-	writeMagLog("magml");
-
 	actions_["magics"] = &XmlMagics::magics;
 	actions_["page"] = &XmlMagics::page;
 
@@ -87,6 +84,7 @@ XmlMagics::XmlMagics() : root_(0),
 	actions_["cartesian"] = &XmlMagics::cartesian;
 	actions_["taylor"] = &XmlMagics::cartesian;
 
+
 	actions_["cylindrical"] = &XmlMagics::geographical;
 	actions_["polar_stereographic"] = &XmlMagics::geographical;
 
@@ -96,6 +94,7 @@ XmlMagics::XmlMagics() : root_(0),
 	actions_["taylorgrid"] = &XmlMagics::taylor;
 	actions_["tephigrid"] = &XmlMagics::tephigrid;
 	actions_["thermo"] = &XmlMagics::cartesian;
+	actions_["tephigram"] = &XmlMagics::cartesian;
 	actions_["grib"] = &XmlMagics::grib;
 	actions_["netcdf"] = &XmlMagics::netcdf;
 	actions_["table"] = &XmlMagics::table;
@@ -133,6 +132,7 @@ XmlMagics::XmlMagics() : root_(0),
 	actions_["epsgraph"] = &XmlMagics::epsgraph;
 	actions_["epsgram"] = &XmlMagics::epsgram;
 	actions_["epswind"] = &XmlMagics::epswind;
+	actions_["capebox"] = &XmlMagics::capebox;
 	actions_["epscloud"] = &XmlMagics::epscloud;
 	actions_["epsbar"] = &XmlMagics::epsbar;
 	actions_["epswave"] = &XmlMagics::epswave;
@@ -755,6 +755,12 @@ void XmlMagics::epsbar(const XmlNode& node)
 	epsbar->set(node);
 	top()->visdef(epsbar);
 }
+void XmlMagics::capebox(const XmlNode& node)
+{
+	CapeBox* cape = new CapeBox();
+	cape->set(node);
+	top()->visdef(cape);
+}
 void XmlMagics::epsshading(const XmlNode& node)
 {
 	EpsShade* eps = new EpsShade();
