@@ -1,20 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file MetaData.h
     \brief Implementation of the Template class MetaData.
@@ -34,6 +26,7 @@
 #include <sys/time.h>
 #include <sys/resource.h>
 
+
 using namespace magics;
 
 MetaDataVisitor::MetaDataVisitor() 
@@ -131,6 +124,25 @@ void MetaDataVisitor::collectMetaData()
 
 	catch ( ...) {}
 
+	if ( !wms_file_.empty() && styles_.size() ) {
+	try  {
+			ofstream out(wms_file_);
+
+			
+		
+			
+
+			
+			for (auto style = styles_.begin(); style != styles_.end(); ++style) {
+				
+				out << **style;
+				
+			}
+			
+			out.close();
+		}
+		catch (...) {}
+	}
 	if ( ! javascript_.empty() ) {
 		try  {
 			ofstream out(javascript_.c_str());
@@ -209,5 +221,34 @@ void MetaDataVisitor::collect()
 	for ( vector<MetaDataVisitor*>::iterator meta = meta_.begin(); meta != meta_.end(); ++meta ) 
 		(*meta)->collectMetaData();
 }
-		
 
+#include "ContourLibrary.h"
+void StyleEntry::print(ostream& s) const
+{
+	
+	StyleLibrary styles = *WebLibrary::styles_;
+	
+
+
+	s << "{\"styles\": [ " << endl;
+	string sep = "    ";
+	for (auto style = styles_.begin(); style != styles_.end(); ++style) {
+		string description = styles.getAttribute(*style, "contour_description", "description to come");
+		string title = styles.getAttribute(*style, "contour_title", "title to come");
+		s << sep << "{\"name\":\"" << *style << "\"";
+		sep = ",\n      ";
+		s << sep << "\"description\":\"" << description << "\"";
+		s << sep << "\"title\":\"" << title << "\"";
+		s << sep << "\"legend\": { \"width\": 350"; 
+		sep = ",\n          ";
+		s << sep << "\"height\": 50 }";
+		sep = "\n    ";
+		s << sep << "}";
+		sep = ",\n    ";
+
+		
+	}
+	s << " 	  ]" << endl;
+	s << "  }" << endl;
+
+}
