@@ -293,7 +293,8 @@ void PolarStereographicProjection::init(double width, double height)
 		PCEnveloppe_->push_back(PaperPoint(xpcmax_, ypcmin_));
 		PCEnveloppe_->push_back(PaperPoint(xpcmin_, ypcmin_));
 
-		//boost::geometry::correct(PCEnveloppe_->polygon_);
+		
+
 
 
 		MagLog::dev() << " Projection definition-->[" << ymin_ << ", " << xmin_ << ", " << xmax_ << ", " << ymax_ << "]" << endl;
@@ -926,7 +927,7 @@ Polyline& PolarStereographicProjection::getUserBoundingBox() const
 	return *userEnveloppe_;
 }
 
-#include <boost/geometry/algorithms/distance.hpp>
+
 double PolarStereographicProjection::patchDistance(double res) const
 {
 	/*
