@@ -44,6 +44,8 @@ public:
 		methods_["method"] = &Epsg::method;
 		initMethods_["geos"] = &Epsg::geosinit;
 		initMethods_["tpers"] = &Epsg::tpersinit;
+		initMethods_["polar_north"] = &Epsg::polarinit;
+		initMethods_["polar_south"] = &Epsg::polarsouthinit;
 	}
 	string name_;
 	string definition_;
@@ -77,6 +79,10 @@ public:
 		if ( initmethod != initMethods_.end() ) {
 			( this->*initmethod->second)(from) ;
 		}
+
+
+
+
 	}
 
 	void geosinit(const Proj4Projection& from) {
@@ -109,6 +115,26 @@ public:
 		
 	}
 
+	void polarinit(const Proj4Projection& from) {
+		
+		ostringstream def;
+		
+		def << "+proj=stere +lat_0=90 +lat_ts=60 +lon_0=" << from.vertical_longitude_;
+		def << " +k=0.994 +x_0=2000000 +y_0=2000000 +ellps=WGS84 +datum=WGS84 +units=m +no_defs";
+		definition_ = def.str();
+		
+	}
+
+	void polarsouthinit(const Proj4Projection& from) {
+		
+		ostringstream def;
+		
+		def << "+proj=stere +lat_0=-90 +lat_ts=-60 +lon_0=" << from.vertical_longitude_;
+		def << " +k=0.994 +x_0=2000000 +y_0=2000000 +ellps=WGS84 +datum=WGS84 +units=m +no_defs";
+		definition_ = def.str();
+		
+	}
+
 
 	double minlon_ ;
 	double minlat_;
@@ -197,7 +223,8 @@ Proj4Projection::Proj4Projection(const string& definition) : definition_(definit
 						gridMinLon_(DBL_MAX),
 						gridMinLat_(DBL_MAX),
 						gridMaxLon_(-DBL_MAX),
-						gridMaxLat_(-DBL_MAX)
+						gridMaxLat_(-DBL_MAX), 
+						wraparound_(false)
 {
 	//init();
 	EpsgConfig config;
@@ -207,7 +234,8 @@ Proj4Projection::Proj4Projection(const string& definition) : definition_(definit
 Proj4Projection::Proj4Projection(): gridMinLon_(DBL_MAX),
 		gridMinLat_(DBL_MAX),
 		gridMaxLon_(-DBL_MAX),
-		gridMaxLat_(-DBL_MAX)
+		gridMaxLat_(-DBL_MAX),
+		wraparound_(false)
 {
 	//init();
 	EpsgConfig config;
@@ -256,6 +284,7 @@ void Proj4Projection::init()
 
 	methods_["geos"] = &Proj4Projection::geos;
 	methods_["tpers"] = &Proj4Projection::geos;
+	methods_["polar"] = &Proj4Projection::conic;
 	methods_["conic"] = &Proj4Projection::conic;
 	methods_["simple"] = &Proj4Projection::simple;
 
@@ -287,6 +316,9 @@ void Proj4Projection::init()
 	askedxmax_ =  std::max(min_pcx_, max_pcx_);
 	askedymin_ =  std::min(min_pcy_, max_pcy_);
 	askedymax_ =  std::max(min_pcy_, max_pcy_);
+
+
+
 }
 
 bool Proj4Projection::addSouth() const {
@@ -342,6 +374,12 @@ void Proj4Projection::full()
 	}
 }
 
+
+void Proj4Projection::wrap(double& x, double& y)
+{
+	
+}
+
 void Proj4Projection::corners()
 {
 	// we have to update the PCBounding box!
@@ -408,6 +446,8 @@ PaperPoint Proj4Projection::operator()(const PaperPoint& point)  const
 
 void Proj4Projection::setNewPCBox(double minx, double miny, double maxx, double maxy)
 {
+
+
 	   PaperPoint p1(minx, miny);
 	   PaperPoint p2(maxx, maxy);
 	   UserPoint   ll, ur;
@@ -520,11 +560,24 @@ void Proj4Projection::simple()
 	min_pcy_ = DBL_MAX;
 	max_pcx_ = -DBL_MAX;
 	max_pcy_ = -DBL_MAX;
+
 	add(projection_->minlon_, projection_->minlat_);
 	add(projection_->minlon_, projection_->maxlat_);
 	add(projection_->maxlon_, projection_->maxlat_);
 	add(projection_->maxlon_, projection_->minlat_);
 	add(projection_->minlon_, projection_->minlat_);
+
+	width_= projection_->maxlon_ - projection_->minlon_;
+
+	double minx = projection_->minlon_;
+	double y1, y2 = (projection_->maxlat_ + projection_->minlat_);
+	double maxx = projection_->maxlon_;
+
+	fast_reproject(minx, y1);
+	fast_reproject(maxx, y1);
+	pwidth_ = maxx - minx;
+
+	wraparound_ = false; 
 }
 
 void Proj4Projection::projectionSimple()
@@ -1170,21 +1223,22 @@ MatrixHandler* Proj4Projection::prepareData(const AbstractMatrix& matrix) const
 
 bool Proj4Projection::fast_reproject(double& x, double& y) const
 {
-
-
+	int factor = 0;
+	if ( wraparound_ ) {
+		factor = int(x/width_);
+		x -=  (factor-width_);
+	}
+	
 	x *= DEG_TO_RAD;
 	y *= DEG_TO_RAD;
 	int error =  pj_transform(from_, to_, 1, 1, &x, &y, NULL );
 
 	if ( error  ) {
-
-
-
 			  //MagLog::warning()  << pj_strerrno(error) << " for " << x << " " << y << endl;		
 			  return false;	  
-
-
 	}
+	if ( wraparound_ ) 
+		x += (factor - pwidth_);
 	return true;
 }
 
@@ -1232,3 +1286,97 @@ void Proj4Projection::setDefinition(const string& json)
 	node.name("");
 	set(node);
 }
+
+
+void  Proj4Automatic::setMinMaxX(double min, double max)
+{
+	
+	min_longitude_ = min;
+	max_longitude_ = max;
+
+}
+
+
+void Proj4Automatic::setMinMaxY(double min, double max)
+{
+
+	
+	min_latitude_ = min;
+	max_latitude_ = max;
+	if ( min_latitude_ > 45 ) {
+		definition_ =      "polar_north";
+        vertical_longitude_ = (min_longitude_ + max_longitude_)/2;
+        MagLog::dev() << "Set Vertical longitude " << vertical_longitude_ << endl;
+        //map_hemisphere_     = "north";
+        setting_ = "corners";
+        min_latitude_ -= 5;
+    }
+    else if ( max_latitude_ < -45 ) {
+		definition_ =      "polar_south";
+        vertical_longitude_ = (min_longitude_ + max_longitude_)/2;
+        MagLog::dev() << "Set Vertical longitude " << vertical_longitude_ << endl;
+        //map_hemisphere_     = "north";
+        setting_ = "corners";
+        max_latitude_ += 10;
+        double swap = min_longitude_;
+        min_longitude_ = max_longitude_;
+        max_longitude_ = swap;
+
+    }
+    else {
+		definition_ = "EPSG:4326";
+		setting_ = "corners";
+	}
+	init_ = true;
+	fill(width_, height_);
+	
+	
+	// Now apply teh aspect ratio and reintialise! 
+	
+	min_latitude_ = gridMinLat_;
+	min_longitude_ = gridMinLon_;
+	max_latitude_ = gridMaxLat_;
+	max_longitude_ =  gridMaxLon_;
+
+	
+
+	init();
+}
+
+void Proj4Automatic::init()
+{
+
+	if ( init_ )
+		Proj4Projection::init();	
+}
+
+Proj4Automatic::Proj4Automatic() : Proj4Projection("automatic"), init_(false)
+{
+	
+}
+
+void Proj4Automatic::aspectRatio(double& width, double& height)
+{
+	
+	width_  = width;
+	height_ = height;
+
+}
+
+
+void Proj4Automatic::setNewPCBox(double minx, double miny, double maxx, double maxy)
+{
+	double x = minx;
+	double y = miny;
+	int error = pj_transform(to_, from_, 1, 1, &x, &y, NULL );
+
+	gridMinLon_ = x * RAD_TO_DEG;
+	gridMinLat_ = y * RAD_TO_DEG;
+
+	x = maxx;
+	y = maxy;
+	error = pj_transform(to_, from_, 1, 1, &x, &y, NULL );
+
+	gridMaxLon_ = x * RAD_TO_DEG;
+	gridMaxLat_ = y * RAD_TO_DEG;
+}
