@@ -1,21 +1,12 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
-
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file SpotDecoder.h
     \brief Implementation of the Template class SpotDecoder.
@@ -1107,7 +1098,7 @@ void EpsParameter::interpretResult(spot_query_result* result, vector<CustomisedP
 			if ( type_ == "eps15" ) 
 				specific15(*point);
 
-		if ( !isnan(values[info->second]) ) {
+		if ( !std::isnan(values[info->second]) ) {
 		  (*point)[x(prefix_, info->first)] = (*this)(values[info->second], info->first);
 		  //MagLog::debug() <<  x(info->first) << "----->" << (*this)(values[info->second], info->first) << endl;
 
@@ -1529,35 +1520,7 @@ MatrixHandler& EpsgramDecoder::matrix()
 	    column++;
 	}
 
-	/*matrix_.set(steps_.size(), heights_.size());
 
-
-	for ( vector<double>::const_iterator height =heights_.begin(); height != heights_.end(); ++height) {
-				matrix_.rowsAxis().push_back(*height);
-	}	
-	MagLog::dev()<< " step-->" <<endl;
-	for ( vector<double>::const_iterator step = steps_.begin(); step != steps_.end(); ++step) {
-				matrix_.columnsAxis().push_back(*step);
-				MagLog::dev()<< *step << " ";
-			}
-			MagLog::dev()<< endl << "<--- step" <<endl;
-			matrix_.setMapsAxis();
-			int i = 0;
-			for ( int height = 0; height < heights_.size(); height++) {
-
-			    MagLog::dev()<< endl <<  heights_[height] << " " << steps_.size() << endl;
-				for ( int step = 0; step < steps_.size(); step++) {
-					matrix_.push_back(values_[(step*heights_.size()) + height]);
-					MagLog::dev()<< matrix_.back() << " ";
-				}
-			}
-				MagLog::debug() << matrix_ << endl;
-	for (vector<CustomisedPoint*>::const_iterator point = points_.begin(); point != points_.end(); ++point)
-	{
-			 MagLog::dev() << **point << endl;
-
-	}
-	*/
 	matrixHandlers_.push_back(new  MatrixHandler(matrix_));
 	return *(matrixHandlers_.back());
 }
