@@ -34,6 +34,17 @@ NetcdfGeoMatrixInterpretor::NetcdfGeoMatrixInterpretor()
 NetcdfGeoMatrixInterpretor::~NetcdfGeoMatrixInterpretor() 
 {}
 
+string NetcdfGeoMatrixInterpretor::proj4Detected(Netcdf& netcdf) 
+{
+	// Efas old netcdf 
+	string proj4 = netcdf.getAttribute("projection", string(""));
+	if ( proj4.size() )
+		return proj4;
+	string mapping = netcdf.getVariableAttribute(field_, "grid_mapping", string(""));
+	if ( mapping.size() )
+		return netcdf.getVariableAttribute(mapping, "proj4_params", string(""));
+	return "";
+}
 
 
 bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** matrix)
@@ -43,7 +54,7 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** matrix)
 	Netcdf netcdf(path_, dimension_method_);
 
 
-	string proj4 = netcdf.getAttribute("projection", string(""));
+	string proj4 = proj4Detected(netcdf);
 
 	if ( proj4.empty() ) {
 		matrix_ = new Matrix();
@@ -62,11 +73,11 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** matrix)
 		settings.askId(needs);
 		for ( auto need = needs.begin(); need != needs.end(); ++need) {
 			need->second = getAttribute(field_, need->first, "");
-			cout << need->first << "--->" << need->second << endl;
+			//cout << need->first << "--->" << need->second << endl;
 		}
 		
 		settings.getScaling(needs, scaling_, offset_);
-		cout << "Apply scaling " << scaling_ << " and " << offset_ << endl; 
+		//cout << "Apply scaling " << scaling_ << " and " << offset_ << endl; 
 	}
 
 
@@ -107,14 +118,16 @@ bool NetcdfGeoMatrixInterpretor::interpretAsMatrix(Matrix** matrix)
 			fill(matrix_->begin(), matrix_->end(), missing_value);
 			for (vector<double>::iterator d = data.begin(); d != data.end(); ++d ) 
 			{
-				if ( !std::isnan(*d) ) {
+				if ( !std::isnan(*d) && !std::isinf(*d) ) {
 					matrix_->push_back(*d);
 					
 				}
+				else 
+					matrix_->push_back(missing_value);
 				i++;			
 			}
 		}
-		cout << "Apply scaling " << scaling_ << " and " << offset_ << endl; 
+		//cout << "Apply scaling " << scaling_ << " and " << offset_ << endl; 
 		matrix_->multiply(scaling_);
 		matrix_->plus(offset_);
 	    matrix_->setMapsAxis();
@@ -172,7 +185,7 @@ void NetcdfGeoMatrixInterpretor::visit(Transformation& transformation) {
 bool NetcdfGeoMatrixInterpretor::interpretAsPoints(PointsList& list)
 {
 	Netcdf netcdf(path_, dimension_method_);
-	string proj4 = netcdf.getAttribute("projection", string(""));
+	string proj4 = proj4Detected(netcdf);
 
 	if ( !proj4.empty() ) {
 		proj4_ = pj_init_plus(proj4.c_str());
