@@ -1,9 +1,9 @@
 /*
  * (C) Copyright 1996-2016 ECMWF.
- * 
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -34,21 +34,20 @@ MgQPatternProperties::MgQPatternProperties(Type type) : type_(type), bg_(QColor(
 
 bool MgQPatternProperties::operator==(const MgQPatternProperties& p) const
 {
-	if(p.type_ != type_) 
+	if(p.type_ != type_)
 		return false;
 
 	if(type_==DotShading)
 	{
 		return p.size_ == size_ && p.itemSize_ == itemSize_ &&
 		       p.bg_ == bg_ && p.colour_ == colour_;
-
 	}
 	else if(type_==HatchShading)
 	{
 		return p.size_ == size_ && p.id_ == id_ && p.lineWidth_ == lineWidth_ &&
 		       p.bg_ == bg_ && p.colour_ == colour_;
-
 	}
+	return false;
 }
 
 //====================================
@@ -66,13 +65,13 @@ MgQPattern::MgQPattern(const MgQPatternProperties &prop) : QPixmap(prop.size_),
 		if(prop_.itemSize_.width() < 1)
 			return;
 
-		QPainter p(this);	
+		QPainter p(this);
 
 		if(prop_.itemSize_.width()== 1)
 		{
 			p.setPen(prop_.colour_);
 			p.drawPoint(width()/2,height()/2);
-			
+
 		}
 		else if(prop_.itemSize_.width() < 4)
 		{
@@ -93,7 +92,7 @@ MgQPattern::MgQPattern(const MgQPatternProperties &prop) : QPixmap(prop.size_),
 	else if(prop.type_ ==  MgQPatternProperties::HatchShading)
 	{
 		fill(prop.bg_);
-			
+
 		QPainter p(this);
 
 		QPen pen(prop_.colour_);
@@ -106,19 +105,19 @@ MgQPattern::MgQPattern(const MgQPatternProperties &prop) : QPixmap(prop.size_),
 		int h=height();
 
 		if(index==1 || index==3) // horizontal
-		{			
-			p.drawLine(QPointF(0,h*0.5),QPointF(w-1,h*0.5));					
-		}		
-		if(index==2 || index==3) // vertical
-		{			
-			p.drawLine(QPointF(w*0.5,0),QPointF(w*0.5,h-1));					
+		{
+			p.drawLine(QPointF(0,h*0.5),QPointF(w-1,h*0.5));
 		}
-		if(index==4 || index==6) 
-		{		
+		if(index==2 || index==3) // vertical
+		{
+			p.drawLine(QPointF(w*0.5,0),QPointF(w*0.5,h-1));
+		}
+		if(index==4 || index==6)
+		{
 			p.drawLine(QPointF(0,0),QPointF(w-1,h-1));
 		}
-		if(index==5 || index==6) 
-		{		
+		if(index==5 || index==6)
+		{
 			p.drawLine(QPointF(0,h-1),QPointF(w-1,0));
 		}
 	}
@@ -131,49 +130,48 @@ MgQPattern::MgQPattern(const MgQPatternProperties &prop) : QPixmap(prop.size_),
 //====================================
 
 MgQPatternManager::~MgQPatternManager()
-{	
+{
 	foreach(MgQPattern *item, patterns_)
-	{		
+	{
 		delete item;
 	}
 }
 
 MgQPattern* MgQPatternManager::getPattern(MgQPatternProperties& p)
-{	
-	foreach(MgQPattern *item, patterns_) 
+{
+	foreach(MgQPattern *item, patterns_)
 	{
 		if( item->properties() == p)
 		{
 			return item;
 		}
 	}
-	
-	return 0;		
+
+	return 0;
 }
 
 MgQPattern* MgQPatternManager::addPattern(MgQPatternProperties& p)
 {
 	MgQPattern *pix = getPattern(p);
 
-	if(pix) 
+	if(pix)
 	{
 		return pix;
 	}
-	
+
 	pix=new MgQPattern(p);
 	patterns_ <<  pix;
-	return pix;	
+	return pix;
 }
 
-void MgQPatternManager::deletePattern(MgQPatternProperties& p)	
-{	
+void MgQPatternManager::deletePattern(MgQPatternProperties& p)
+{
 	foreach(MgQPattern *item, patterns_)
 	{
 		if( item->properties() == p)
 		{
 			delete item;
 			return;
-		}	
+		}
 	}
-}	
-
+}
