@@ -26,11 +26,12 @@
 #include "ContourLibrary.h"
 #include "HistoVisitor.h"
 #include "Timer.h"
+#include "MetaData.h"
 
 using namespace magics;
 
 
-Contour::Contour() : matrix_(0)
+Contour::Contour() : matrix_(0), styleInfo_(0)
 {
 }
 
@@ -38,6 +39,7 @@ Contour::Contour() : matrix_(0)
 Contour::~Contour()
 {
 	if (matrix_) delete(matrix_);
+	if ( styleInfo_) delete (styleInfo_);
 }
 
 /*!
@@ -76,36 +78,70 @@ void Contour::operator()(Data& data, BasicGraphicsObjectContainer& parent)
 {
 
     try {
-    	ContourLibrary* library = MagTranslator<string, ContourLibrary>()(setting_);
+		ParameterManager::set("contour_automatic_library_path", library_path_);
+		ContourLibrary* library = MagTranslator<string, ContourLibrary>()(setting_);
+		
+		MetaDataCollector request,needAttributes;
+		MagDef attributes;
 
-    		// Here we try call the Contour libry to set up visual properties...
-    		MetaDataCollector request,needAttributes;
-    		map<string, string> attributes;
+    	bool legend_only = contour_->legend_only_;
+    	if ( predefined_.size() ) {
     		
-
-		library->askId(request);
-		data.visit(request);
-
-
-		if(library->checkId(request,needAttributes))
-		{			
-    			data.visit(needAttributes);
-    			needAttributes["theme"] = theme_;
-    			library->getStyle(needAttributes,attributes);
-    			if ( !legend_ ) 
-    				attributes["legend"] ="off";
-    			set(attributes);
+    		library->getStyle(predefined_, attributes);
+    		for (auto s = attributes.begin(); s != attributes.end(); ++s)
+    			cout << s->first << "-->" << s->second << endl;
+    		
+    		set(attributes);
+    		auto text = attributes.find("contour_legend_text");
+			if ( text != attributes.end() )
+				ParameterManager::set("contour_legend_text", text->second);
     	}
-		else {
-			
-			request["theme"] = theme_;
-			library->getStyle(request,attributes);
-			if ( !legend_ ) 
-				attributes["legend"] ="off";
-			set(attributes);
-		}
+    	else { 
+			library->askId(request);
+			data.visit(request);
+
+			if(library->checkId(request,needAttributes))
+			{			
+	    			data.visit(needAttributes);
+	    			needAttributes["theme"] = theme_;
+	    			library->getStyle(needAttributes,attributes, *styleInfo_);
+	    			if ( !legend_ ) 
+	    				attributes["legend"] ="off";
+	    			set(attributes);
+
+	    	}
+			else {
+				
+				request["theme"] = theme_;
+				styleInfo_ = new StyleEntry();
+
+				library->getStyle(request, attributes, *styleInfo_);
+				
+				
+				attributes["contour_legend_only"] = contour_->legend_only_;
+				
+				if ( !legend_ ) 
+					attributes["legend"] ="off";
+				if (metadata_only_) 
+					attributes["contour_legend_only"] = "on";
+				set(attributes);
+				/*
+				for (auto s = attributes.begin(); s != attributes.end(); ++s)
+    				cout << s->first << "-->" << s->second << endl;
+    			*/
+				auto text = attributes.find("contour_legend_text");
+				if ( text != attributes.end() )
+					ParameterManager::set("contour_legend_text", text->second);
+
+			}
+
+		}	
+
+		contour_->legend_only_ = legend_only;
+
 		delete library;
 
+
 		
 
     data.getReady(parent.transformation());
@@ -179,10 +215,12 @@ void  Contour::visit(Data& data, HistoVisitor& visitor)
 	contour_->visit(data, data.points(*visitor.dataLayoutTransformation(), false), visitor);	
 }
 
-static SimpleObjectMaker<ContourLibrary, ContourLibrary> obstat("on");
+
 static SimpleObjectMaker<EcChartLibrary, ContourLibrary> ecchart("ecchart");
 static SimpleObjectMaker<NoContourLibrary, ContourLibrary> off("off");
-static SimpleObjectMaker<WebLibrary, ContourLibrary> web("web");
+static SimpleObjectMaker<WebLibrary, ContourLibrary> style_name("style_name");
+static SimpleObjectMaker<WebLibrary, ContourLibrary> ecmwf("ecmwf");
+
 
 void Contour::visit(Data& data, LegendVisitor& legend)
 {
@@ -190,3 +228,10 @@ void Contour::visit(Data& data, LegendVisitor& legend)
 	contour_->visit(data, legend);
 }
 
+void Contour::visit(MetaDataVisitor& visitor) {
+
+
+if ( styleInfo_ )
+	visitor.add(styleInfo_);
+	styleInfo_ = 0;
+}
