@@ -1,30 +1,22 @@
-/******************************** LICENSE ********************************
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- you may not use this file except in compliance with the License.
- You may obtain a copy of the License at 
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ *
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file PolyShadingMethod.h
     \brief Definition of the Template class PolyShadingMethod.
-    
+
     Magics Team - ECMWF 2004
-    
+
     Started: Wed 18-Aug-2004
-    
+
     Changes:cc
-    
+
 */
 
 
@@ -37,27 +29,28 @@ using namespace magics;
 
 
 
-	
-    
 void PolyShadingMethod::operator()(Polyline& poly) const
-    {
-       
+{
 		int index = poly.index();
-		if (index < 0  ) 
+		if (index < 0  )
 			return;
-        poly.setFilled(true);      
-        poly.setStroke(false);
         poly.setFilled(true);
-        if ( index >= colours_.size() )
-            poly.setFillColour(colours_.back());
-        else 
-            poly.setFillColour(colours_[index]);
-        FillShadingProperties* shading = new FillShadingProperties();                      
+        poly.setStroke(true);
+        poly.setFilled(true);
+        if ( index >= colours_.size() ){
+					poly.setColour(colours_.back());
+					poly.setFillColour(colours_.back());
+				}
+        else{
+					poly.setColour(colours_[index]);
+					poly.setFillColour(colours_[index]);
+				}
+        FillShadingProperties* shading = new FillShadingProperties();
         poly.setShading(shading);
-    };
-   
+};
+
 void  PolyShadingMethod::visit(LegendVisitor& legend, const ColourTechnique& colour) {
-        
+
         MagLog::dev() << "Create legend information"  << "\n";
         LegendEntryBuilder helper(legend, colour);
         std::adjacent_find(colour.begin(), colour.end(), LegendEntryBuilder(legend, this, colour));
@@ -65,13 +58,10 @@ void  PolyShadingMethod::visit(LegendVisitor& legend, const ColourTechnique& col
         		helper(*colour.begin(), *colour.begin());
         	}
         legend.last(); // Flag the last entry as being the last! To get a nice labelling in countinuous mode!!!
-        
-    }
+}
 
 int PolyShadingMethod::index(double value)
 {
-
-
 	if ( same(value, last_) )
 		return indexes_.size() -1;
 	return indexes_.find(value, -1);
@@ -91,22 +81,18 @@ int PolyShadingMethod::leftIndex(double value)
 	if ( same(value, last_) )  return indexes_.size() -1;
 	int index = indexes_.find(value, -1);
 	return  ( index == -1 ) ? - 1 : index -1;
-
 }
-void PolyShadingMethod::prepare(const LevelSelection& levels, const ColourTechnique& colours)
-{
 
+void PolyShadingMethod::prepare(LevelSelection& levels, const ColourTechnique& colours)
+{
 	if (levels.empty() )return;
 	first_ = levels.front();
 	last_ =  levels.back();
 
-
 	LevelSelection::const_iterator from = levels.begin();
 	LevelSelection::const_iterator level = levels.begin();
 	level++;
 
-
-
 	indexes_.clear();
 	colours_.clear();
 
@@ -116,15 +102,12 @@ void PolyShadingMethod::prepare(const LevelSelection& levels, const ColourTechni
 		colours_.push_back(colours.right(*from));
 		from++;
 		index++;
-
-
 	}
-
 }
 
 
 
-void DotPolyShadingMethod::prepare(const LevelSelection& levels, const ColourTechnique& colours)
+void DotPolyShadingMethod::prepare(LevelSelection& levels, const ColourTechnique& colours)
 {
 	if (levels.empty() )return;
 
@@ -141,48 +124,41 @@ void DotPolyShadingMethod::prepare(const LevelSelection& levels, const ColourTec
 	colours_.clear();
 	dots_.clear();
 	for (  ;  level != levels.end(); ++level) {
-
 		indexes_.insert(make_pair(Interval(*from, *level), index));
 		colours_.push_back(colours.right(*from));
 		dots_.push_back(density);
 		from++;
 		index++;
 		density+=step;
-
 	}
-
 }
 
 
 void  DotPolyShadingMethod::operator()(Polyline& poly) const {
     DotShadingProperties* shading = new DotShadingProperties();
 
-
     int index = poly.index();
 
-
-
-
     shading->size_ = size_;
     shading->density_ =  dots_[index];
 
     poly.setFilled(true);
     poly.setFillColour(colours_[index]);
-	poly.setStroke(false);
+		poly.setStroke(false);
     poly.setShading(shading);
     //MagLog::dev() << "Attach DotShading Information" << *shading << "\n";
 }
 
 
 
-void HatchPolyShadingMethod::prepare(const LevelSelection& levels, const ColourTechnique& colours) {
+void HatchPolyShadingMethod::prepare(LevelSelection& levels, const ColourTechnique& colours) {
    	int index = 1;
    	if (index_ >= 7 || index_ <0) {
    		MagLog::warning() << "index should be < 7--> reset to 1 "<< endl;
    		index_ = 1 ;
    	}
    	first_ = levels.front();
-	last_ =  levels.back();
+		last_ =  levels.back();
 
    	LevelSelection::const_iterator from = levels.begin();
    	LevelSelection::const_iterator level = levels.begin();
@@ -190,7 +166,7 @@ void HatchPolyShadingMethod::prepare(const LevelSelection& levels, const ColourT
    	colours_.clear();
    	hatches_.clear();
 
-	level++;
+		level++;
    	int i = 0;
 
    	for (  ;  level != levels.end(); ++level) {
@@ -202,10 +178,7 @@ void HatchPolyShadingMethod::prepare(const LevelSelection& levels, const ColourT
    		from++;
    		if ( index == 7 ) index = 1;
    	}
-
-
-
-   }
+}
 
 void HatchPolyShadingMethod::operator()(Polyline& poly) const
 {
@@ -220,7 +193,4 @@ void HatchPolyShadingMethod::operator()(Polyline& poly) const
        poly.setFillColour(colours_[index]);
        poly.setStroke(false);
        poly.setShading(shading);
-
 }
-
-
